==> speech-dispatcher-0.10.2-x86_64-2slint.txz: install/doinst.sh <==
( cd usr/share/sounds/sound-icons ; rm -rf message )
( cd usr/share/sounds/sound-icons ; ln -sf cymbaly-1.wav message )
( cd usr/share/sounds/sound-icons ; rm -rf end-of-line )
( cd usr/share/sounds/sound-icons ; ln -sf violoncello-7.wav end-of-line )
( cd usr/share/sounds/sound-icons ; rm -rf at )
( cd usr/share/sounds/sound-icons ; ln -sf cembalo-6.wav at )
( cd usr/share/sounds/sound-icons ; rm -rf right-brace )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-down-cink.wav right-brace )
( cd usr/share/sounds/sound-icons ; rm -rf start )
( cd usr/share/sounds/sound-icons ; ln -sf xylofon.wav start )
( cd usr/share/sounds/sound-icons ; rm -rf left-round-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-up.wav left-round-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf pipe )
( cd usr/share/sounds/sound-icons ; ln -sf pipe.wav pipe )
( cd usr/share/sounds/sound-icons ; rm -rf finish )
( cd usr/share/sounds/sound-icons ; ln -sf trumpet-1.wav finish )
( cd usr/share/sounds/sound-icons ; rm -rf prompt )
( cd usr/share/sounds/sound-icons ; ln -sf prompt.wav prompt )
( cd usr/share/sounds/sound-icons ; rm -rf left-square-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf guitar-13.wav left-square-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf right-round-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-down.wav right-round-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf capital )
( cd usr/share/sounds/sound-icons ; ln -sf percussion-10.wav capital )
( cd usr/share/sounds/sound-icons ; rm -rf empty-text )
( cd usr/share/sounds/sound-icons ; ln -sf gummy-cat-2.wav empty-text )
( cd usr/share/sounds/sound-icons ; rm -rf beginning-of-line )
( cd usr/share/sounds/sound-icons ; ln -sf glass-water-1.wav beginning-of-line )
( cd usr/share/sounds/sound-icons ; rm -rf hash )
( cd usr/share/sounds/sound-icons ; ln -sf percussion-28.wav hash )
( cd usr/share/sounds/sound-icons ; rm -rf left-brace )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-up-cink.wav left-brace )
( cd usr/share/sounds/sound-icons ; rm -rf right-square-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf guitar-12.wav right-square-bracket )
( cd usr/share/speech-dispatcher/locale/es_VE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/lib64 ; rm -rf libspeechd.so )
( cd usr/lib64 ; ln -sf libspeechd.so.2.6.0 libspeechd.so )
( cd usr/lib64 ; rm -rf libspeechd.so.2 )
( cd usr/lib64 ; ln -sf libspeechd.so.2.6.0 libspeechd.so.2 )

#Added by slkbuild 1.2
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
dotnew etc/speech-dispatcher/modules/espeak-ng-mbrola-generic.conf
dotnew etc/speech-dispatcher/modules/rhvoice.conf
dotnew etc/speech-dispatcher/modules/pico.conf
dotnew etc/speech-dispatcher/modules/voxin.conf
dotnew etc/speech-dispatcher/modules/flite-generic.conf
dotnew etc/speech-dispatcher/modules/flite.conf
dotnew etc/speech-dispatcher/modules/espeak-ng.conf
dotnew etc/speech-dispatcher/speechd.conf
dotnew etc/speech-dispatcher/clients/emacs.conf

==> speech-dispatcher-0.11.0rc5-x86_64-1slint.txz: install/doinst.sh <==
( cd usr/libexec/speech-dispatcher-modules ; rm -rf sd_espeak-ng-mbrola )
( cd usr/libexec/speech-dispatcher-modules ; ln -sf sd_espeak-ng sd_espeak-ng-mbrola )
( cd usr/share/sounds/sound-icons ; rm -rf message )
( cd usr/share/sounds/sound-icons ; ln -sf cymbaly-1.wav message )
( cd usr/share/sounds/sound-icons ; rm -rf end-of-line )
( cd usr/share/sounds/sound-icons ; ln -sf violoncello-7.wav end-of-line )
( cd usr/share/sounds/sound-icons ; rm -rf at )
( cd usr/share/sounds/sound-icons ; ln -sf cembalo-6.wav at )
( cd usr/share/sounds/sound-icons ; rm -rf right-brace )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-down-cink.wav right-brace )
( cd usr/share/sounds/sound-icons ; rm -rf start )
( cd usr/share/sounds/sound-icons ; ln -sf xylofon.wav start )
( cd usr/share/sounds/sound-icons ; rm -rf left-round-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-up.wav left-round-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf pipe )
( cd usr/share/sounds/sound-icons ; ln -sf pipe.wav pipe )
( cd usr/share/sounds/sound-icons ; rm -rf finish )
( cd usr/share/sounds/sound-icons ; ln -sf trumpet-1.wav finish )
( cd usr/share/sounds/sound-icons ; rm -rf prompt )
( cd usr/share/sounds/sound-icons ; ln -sf prompt.wav prompt )
( cd usr/share/sounds/sound-icons ; rm -rf left-square-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf guitar-13.wav left-square-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf right-round-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-down.wav right-round-bracket )
( cd usr/share/sounds/sound-icons ; rm -rf capital )
( cd usr/share/sounds/sound-icons ; ln -sf percussion-10.wav capital )
( cd usr/share/sounds/sound-icons ; rm -rf empty-text )
( cd usr/share/sounds/sound-icons ; ln -sf gummy-cat-2.wav empty-text )
( cd usr/share/sounds/sound-icons ; rm -rf beginning-of-line )
( cd usr/share/sounds/sound-icons ; ln -sf glass-water-1.wav beginning-of-line )
( cd usr/share/sounds/sound-icons ; rm -rf hash )
( cd usr/share/sounds/sound-icons ; ln -sf percussion-28.wav hash )
( cd usr/share/sounds/sound-icons ; rm -rf left-brace )
( cd usr/share/sounds/sound-icons ; ln -sf pisk-up-cink.wav left-brace )
( cd usr/share/sounds/sound-icons ; rm -rf right-square-bracket )
( cd usr/share/sounds/sound-icons ; ln -sf guitar-12.wav right-square-bracket )
( cd usr/share/speech-dispatcher/locale/es_VE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/lib64 ; rm -rf libspeechd.so )
( cd usr/lib64 ; ln -sf libspeechd.so.2.6.0 libspeechd.so )
( cd usr/lib64 ; rm -rf libspeechd.so.2 )
( cd usr/lib64 ; ln -sf libspeechd.so.2.6.0 libspeechd.so.2 )

#Added by slkbuild 1.2
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
dotnew etc/speech-dispatcher/modules/rhvoice.conf
dotnew etc/speech-dispatcher/modules/pico.conf
dotnew etc/speech-dispatcher/modules/voxin.conf
dotnew etc/speech-dispatcher/modules/flite-generic.conf
dotnew etc/speech-dispatcher/modules/espeak-ng-mbrola.conf
dotnew etc/speech-dispatcher/modules/mary-generic.conf
dotnew etc/speech-dispatcher/modules/flite.conf
dotnew etc/speech-dispatcher/modules/espeak-ng.conf
dotnew etc/speech-dispatcher/speechd.conf
dotnew etc/speech-dispatcher/clients/emacs.conf
doinst () 
{ 
    if [ -f /etc/speech-dispatcher/modules/espeak-ng-mbrola-generic.conf ]; then
        rm -f /etc/speech-dispatcher/modules/espeak-ng-mbrola-generic.conf;
    fi
}
doinst
